-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

local M = {}
M.type = "auxiliary"

local odometer = 0
local wear = 0

local function updatePowertrainDamage()
  
  local integrity = 1 - wear
  
  for _, d in pairs(powertrain.getDevices()) do
    if not d.isBroken then
	  if d.type ~= "torsionReactor" and d.type ~= "electricMotor" and d.type ~= "electricServo" and d.type ~= "multiShaft" then
	    d.setPartCondition(d, nil, odometer, integrity, nil)
	    if d.name == "mainEngine" and d.getPartCondition(d) == 1 then
	      if d.thermals.getPartConditionExhaust(d) == 1 then 
		    d.setPartCondition(d, "exhaust", odometer, integrity, nil) 
		  end
		  if d.thermals.getPartConditionRadiator(d) == 1 then 
		    d.setPartCondition(d, "radiator", odometer, integrity, nil) 
		  end
		  if d.turbocharger and d.turbocharger.getPartCondition(d.turbocharger) == 1 then 
		    d.setPartCondition(d, "turbocharger", odometer, integrity, nil) 
		  end
	    end
	  end
	end
  end
  
  for _, s in pairs(energyStorage.getStorages()) do
    if not s.isBroken and s.getPartCondition(s) == 1 then
	  s.setPartCondition(s, nil, odometer, integrity, nil)
	end
  end

end


local function reset()
  
  updatePowertrainDamage()
  
end


local function init(jbeamData)
  
  odometer = jbeamData.odometer or 50000000
  wear = jbeamData.wear or 0.5
  
  reset()
  
end


local function updateGFX(dt)

  if not electrics.values.odometer then return end
  odometer = odometer + electrics.values.odometer
  updatePowertrainDamage()

end


-- public interface
M.init      			 = init
M.reset     			 = reset
M.updateGFX				 = updateGFX
M.updatePowertrainDamage = updatePowertrainDamage

return M
