-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

local M = {}
M.type = "auxiliary"

-- suspension node names
local node1
local node2
local node3
local node4

local jumpcooldown
local maxjumpcooldown
local thrustersactive

local timebetweenjumps
local cooldownbetweenjumps
local particledensity
local canjump

local lastCheckedJumpValue -- allows using an input device axis as shooting control, not just on/off buttons

local function init(jbeamData)
  
  electrics.values.jump = 0

  maxjumpcooldown = 0.35 -- max length of jump
  jumpcooldown = maxjumpcooldown -- time until end of jump
  lastCheckedJumpValue = 0
  thrustersactive = 1 -- if thrusters are enabled (are not being used atm)
  cooldownbetweenjumps = jbeamData.cooldown or 5
  particledensity = jbeamData.particledensity or 0.25
  timebetweenjumps = 0
  canjump = 1
  
  -- assign the code to node names
  for k, node in pairs (v.data.nodes) do
    if node.name == jbeamData.explosionNode1 then node1=k  end
	if node.name == jbeamData.explosionNode2 then node2=k  end
	if node.name == jbeamData.explosionNode3 then node3=k  end
	if node.name == jbeamData.explosionNode4 then node4=k  end
  end
end

local function updateGFX(dt) -- ms

  jumpcooldown = jumpcooldown - dt
  
  --if timebetweenjumps <= 0 then gui.message("Cooldown: 0, can jump!") end
  
  if timebetweenjumps > 0 then
    timebetweenjumps = timebetweenjumps - dt 
	--gui.message("Cooldown: " .. timebetweenjumps)  
  end
  
  -- code for input device
  
  if electrics.values.jump < 0.9 then
     --axis/button is not being pressed down far enough, ignore this event
    lastCheckedJumpValue = electrics.values.jump
    return
  end

  if electrics.values.jump < lastCheckedJumpValue then return end -- ignore event if user is in the process of releasing the button/axis (even when above firing threshold)

  if jumpcooldown < 0 then -- only jump if cooldown has passed 

	   -- SFX PART
	 
	if thrustersactive == 1 then -- play sound only when the thrusters are NOT being used, otherwise it would play after the jump is finished

	  if timebetweenjumps <= 0 then -- don't play when can't activate jump
		
        obj:playSFXOnce("event:>Special>cannon_fire", node1, 1, 1)
        obj:playSFXOnce("event:>Special>cannon_fire", node2, 1, 1)
        obj:playSFXOnce("event:>Special>cannon_fire", node3, 1, 1)
        obj:playSFXOnce("event:>Special>cannon_fire", node4, 1, 1)

	  end
	  
	end
		
	electrics.values.jump = 0 
	if timebetweenjumps > 0 then -- disable jumping on cooldown
	  canjump = 0 
	  gui.message("Jump system is on cooldown...")  
	end 
	jumpcooldown = maxjumpcooldown
	
  end
  
  if timebetweenjumps <= 0 then -- enable jump after cooldown
    canjump = 1
	--gui.message("Cooldown over, jump enabled!")  
  end 
  
  electrics.values.jump = electrics.values.jump * canjump
    
  lastCheckedJumpValue = electrics.values.jump
  thrustersactive = 1 -- after jump enable thrusters
  
  
  -- GFX PART
  
  if electrics.values.jump == 1 then
	
	timebetweenjumps = cooldownbetweenjumps -- enable cooldown between jumps
	
	obj:addParticleByNodesRelative(node1, node1, 5, 49, 1, particledensity)
    obj:addParticleByNodesRelative(node1, node1, 5, 29, 1, particledensity)
    obj:addParticleByNodesRelative(node1, node1, 5, 37, 1, particledensity)
	  
	obj:addParticleByNodesRelative(node2, node2, 5, 49, 1, particledensity)
    obj:addParticleByNodesRelative(node2, node2, 5, 29, 1, particledensity)
    obj:addParticleByNodesRelative(node2, node2, 5, 37, 1, particledensity)
	  
	obj:addParticleByNodesRelative(node3, node3, 5, 49, 1, particledensity)
    obj:addParticleByNodesRelative(node3, node3, 5, 29, 1, particledensity)
    obj:addParticleByNodesRelative(node3, node3, 5, 37, 1, particledensity)
	  
	obj:addParticleByNodesRelative(node4, node4, 5, 49, 1, particledensity)
    obj:addParticleByNodesRelative(node4, node4, 5, 29, 1, particledensity)
    obj:addParticleByNodesRelative(node4, node4, 5, 37, 1, particledensity)
	
	thrustersactive = 0 -- during jump disable thrusters
	
  end

end


-- public interface
M.init    = init
M.updateGFX = updateGFX

return M
